/* 
 *	HT Editor
 *	process.h
 *
 *	Copyright (C) 1999-2002 Stefan Weyergraf
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 2 as
 *	published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __PROCESS_H__
#define __PROCESS_H__

#include "common.h"
#include "htdata.h"
#include "htobj.h"

typedef bool (*process_func)(Object *context, ht_text *progress_indicator);

bool execute_process(process_func pp, Object *context);

#endif /* __PROCESS_H__ */
